<?php
if (!defined('ABSPATH')) {
    exit;
}

// 自動更新のスケジュール設定
function schedule_horoscope_updates() {
    if (!wp_next_scheduled('daily_horoscope_update')) {
        // 日本時間の午前0時（UTCでは前日15時）にスケジュール
        wp_schedule_event(strtotime('15:00:00'), 'daily', 'daily_horoscope_update');
    }

    if (!wp_next_scheduled('horoscope_cleanup')) {
        wp_schedule_event(time(), 'daily', 'horoscope_cleanup');
    }
}
add_action('wp', 'schedule_horoscope_updates');

// 古いデータの自動削除（10日以上経過）
function cleanup_old_horoscopes() {
    $args = array(
        'post_type' => 'horoscope',
        'posts_per_page' => -1,
        'meta_query' => array(
            array(
                'key' => 'horoscope_date',
                'value' => date('Y-m-d', strtotime('-10 days')),
                'compare' => '<',
                'type' => 'DATE'
            )
        )
    );

    $query = new WP_Query($args);
    if ($query->have_posts()) {
        while ($query->have_posts()) {
            $query->the_post();
            wp_delete_post(get_the_ID(), true);
        }
    }
    wp_reset_postdata();
    
    error_log(date('Y-m-d H:i:s') . ': 古い運勢データを削除しました。');
}
add_action('horoscope_cleanup', 'cleanup_old_horoscopes');

// 自動更新通知
function perform_daily_horoscope_check() {
    $zodiac_signs = array(
        'aries' => '牡羊座', 'taurus' => '牡牛座', 'gemini' => '双子座', 'cancer' => '蟹座',
        'leo' => '獅子座', 'virgo' => '乙女座', 'libra' => '天秤座', 'scorpio' => '蠍座',
        'sagittarius' => '射手座', 'capricorn' => '山羊座', 'aquarius' => '水瓶座', 'pisces' => '魚座'
    );

    $today = current_time('Y-m-d');
    $missing_signs = array();
    
    foreach ($zodiac_signs as $sign => $name) {
        if (!get_horoscope($sign, $today)) {
            $missing_signs[] = $name;
        }
    }

    if (!empty($missing_signs)) {
        $admin_email = get_option('admin_email');
        $subject = '運勢予報の更新が必要です（' . $today . '）';
        $message = "以下の星座の本日の運勢が未設定です：\n\n";
        $message .= implode("\n", $missing_signs);
        $message .= "\n\n管理画面から運勢を入力してください：\n";
        $message .= admin_url('admin.php?page=horoscope-admin');
        
        wp_mail($admin_email, $subject, $message);
    }
}
add_action('daily_horoscope_update', 'perform_daily_horoscope_check');

// 自動更新ステータスのセクションを追加
function add_horoscope_status_section() {
    add_settings_section(
        'horoscope_status_section',
        '自動更新ステータス',
        'horoscope_status_section_callback',
        'horoscope-settings'
    );
}
add_action('admin_init', 'add_horoscope_status_section');

function horoscope_status_section_callback() {
    $next_update = wp_next_scheduled('daily_horoscope_update');
    $next_cleanup = wp_next_scheduled('horoscope_cleanup');
    ?>
    <div class="horoscope-status">
        <p>
            <strong>次回の自動更新：</strong>
            <?php echo $next_update ? date_i18n('Y年m月d日 H:i', $next_update + (9 * 3600)) : '未設定'; ?>
        </p>
        <p>
            <strong>次回のデータクリーンアップ：</strong>
            <?php echo $next_cleanup ? date_i18n('Y年m月d日 H:i', $next_cleanup + (9 * 3600)) : '未設定'; ?>
        </p>
        <p class="description">
            ・毎日午前0時に自動更新チェックを実行します<br>
            ・10日以上経過した運勢データは自動的に削除されます<br>
            ・未入力の運勢がある場合は管理者にメール通知が送られます
        </p>
    </div>
    <?php
}
?>